/**
  ******************************************************************************
  * @file I2C/M24C08_EEPROM/main.c 
  * @author  MCD Application Team
  * @version  V3.0.0
  * @date  04/06/2009
  * @brief  Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 

/* Includes ------------------------------------------------------------------*/
#include <stdio.h>                          /* standard I/O .h-file           */
#include <ctype.h>                          /* character functions            */
#include "stm32f10x.h"
#include "platform_config.h"
#include "i2c_ee.h"
#include "measure.h"

/** @addtogroup StdPeriph_Examples
  * @{
  */

/** @addtogroup I2C_M24C08_EEPROM
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
typedef enum {FAILED = 0, PASSED = !FAILED} TestStatus;

/* Private define ------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
uint8_t Tx1_Buffer[256];
uint8_t Rx1_Buffer[256];
volatile TestStatus TransferStatus1 = FAILED;
USART_InitTypeDef USART_InitStructure;
char ERROR_STR [] = "\n: %s\n";    /* ERROR message string in code   */
const char menu[] =
   "\n"
   "+************  24C02дԳ ************+\n"
   "|     ʵ˶24C02оƬдԡ24C02 |\n"
   "| 256ֽڵĴ洢ռ䣬ҳСΪ8ֽڣ԰ֽڻҳ |\n"
   "| дIAR5.4Keil MDK 3.8ȫͨ   |\n"
   "|     ʹþ                                       |\n"
   "|     r 50:20 0x50ַ0x20(32)ֽ           |\n"
   "|     w 50:02 0x50ַд0x02(2)ֽ        |\n"
   "|             ȻҪд磺55 AA(Կոָ)|\n"
   "|                                                      |\n"
   "|                                   ˣ³     |\n"
   "|                                   ԱID: STM320     |\n"
   "|                                   QQ: 821457206    |\n"
   "|                                   ʱ䣺2011.11.07   |\n"
   "+ ˵ --+ ﷨ ---------------------------------------+\n"
   "|      | R(r)dd:tt ַ(0x00--0xFF):(0x01--0x100)|\n"
   "| д     | W(w)dd:tt ַ(0x00--0xFF):(0x01--0x100)|\n"
   "+--------+---------------------------------------------+\n";
    
/* Private functions ---------------------------------------------------------*/
void RCC_Configuration(void);
void GPIOUTx_Configuration(void);
void USARTx_configuration(void);
TestStatus Buffercmp(uint8_t* pBuffer1, uint8_t* pBuffer2, uint16_t BufferLength);
void read_eeprom (char * buffer);
void write_eeprom (char * buffer);

/**
  * @brief  Main program
  * @param  None
  * @retval : None
  */
int main(void)
{
  char cmdbuf [15];                            /* command input buffer        */

  int i;                                       /* index for command buffer    */

  /* System clocks configuration ---------------------------------------------*/
  RCC_Configuration();

  /* GPIOUTx configuration ------------------------------------------------------*/
  GPIOUTx_Configuration();

  /* USARTx configuration ----------------------------------------------------*/
  USARTx_configuration();

  /* Initialize the I2C EEPROM driver ----------------------------------------*/
  I2C_EE_Init();  

  printf ( menu );                             /* display command menu        */
  while (1)
  {	     
    printf ("\n: ");
    getline (&cmdbuf[0], sizeof (cmdbuf));     /* input command line          */

    for (i = 0; cmdbuf[i] != 0; i++)  {        /* convert to upper characters */
      cmdbuf[i] = toupper(cmdbuf[i]);
    }

    for (i = 0; cmdbuf[i] == ' '; i++);        /* skip blanks                 */
	switch (cmdbuf[i])  {                      /* proceed to command function */

      case 'R':                                /* Read circular Buffer        */
	    read_eeprom(&cmdbuf[i+1]);
        break;

      case 'W':                                /* Write circular Buffer       */
		write_eeprom(&cmdbuf[i+1]);
        break;

      default:                                 /* Error Handling              */
        printf (ERROR_STR, "δ֪");
        printf (menu);                         /* display command menu        */
        break;
    }
  }
}

/**
  * @brief  Configures the different system clocks.
  * @param  None
  * @retval : None
  */
void RCC_Configuration(void)
{
  /* Setup the microcontroller system. Initialize the Embedded Flash Interface,  
     initialize the PLL and update the SystemFrequency variable. */
  SystemInit();

/* Enable peripheral clocks --------------------------------------------------*/
  /* GPIOB Periph clock enable */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);
  /* I2C1 Periph clock enable */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_I2C1, ENABLE);

  /* Enable GPIOx clock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOx, ENABLE);

/* Enable USARTx clocks */
#ifdef USE_USART1  
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_USART1, ENABLE);
#else
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_USARTx, ENABLE);
#endif
}

/**
  * @brief  Configures the different GPIOUTx ports.
  * @param  None
  * @retval : None
  */
void GPIOUTx_Configuration(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

#if defined USE_USART2	&& defined USE_STM3210B_EVAL
  /* Enable AFIO clock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO, ENABLE);

  /* Enable the USART2 Pins Software Remapping */
  GPIO_PinRemapConfig(GPIO_Remap_USART2, ENABLE);
#endif

  /* Configure USARTx_Tx as alternate function push-pull */
  GPIO_InitStructure.GPIO_Pin = GPIO_TxPin;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOx, &GPIO_InitStructure);

  /* Configure USARTx_Rx as input floating */
  GPIO_InitStructure.GPIO_Pin = GPIO_RxPin;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_Init(GPIOx, &GPIO_InitStructure);
}

/**
  * @brief  Configures the USARTx.
  * @param  None
  * @retval : None
  */
void USARTx_configuration(void)
{
/* USARTx configuration ------------------------------------------------------*/
  /* USARTx configured as follow:
        - BaudRate = 115200 baud  
        - Word Length = 8 Bits
        - One Stop Bit
        - No parity
        - Hardware flow control disabled (RTS and CTS signals)
        - Receive and transmit enabled
  */
  USART_InitStructure.USART_BaudRate = 115200;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No ;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
  
  /* Configure the USARTx */ 
  USART_Init(USARTx, &USART_InitStructure);
  /* Enable the USARTx */
  USART_Cmd(USARTx, ENABLE);
}

/**
  * @brief  Compares two buffers.
  * @param pBuffer1, pBuffer2: buffers to be compared.
  * @param BufferLength: buffer's length
  * @retval : PASSED: pBuffer1 identical to pBuffer2
  *   FAILED: pBuffer1 differs from pBuffer2
  */
TestStatus Buffercmp(uint8_t* pBuffer1, uint8_t* pBuffer2, uint16_t BufferLength)
{
  while(BufferLength--)
  {
    if(*pBuffer1 != *pBuffer2)
    {
      return FAILED;
    }
    
    pBuffer1++;
    pBuffer2++;
  }

  return PASSED;  
}

/*------------------------------------------------------------------------------
  Read EEPROM
*------------------------------------------------------------------------------*/
void read_eeprom (char * buffer)
{
  int adr, num;                          /* temporary time values             */
  int args;                              /* number of arguments               */
  int i, j;

  args = sscanf (buffer, "%x:%x",        /* scan input line for               */
                 &adr,                   /* adr, num                          */
                 &num);
  if (adr > 255  ||  num > 256 ||        /* check for valid inputs            */
      args < 1   ||  args == EOF)  {
    printf (ERROR_STR, "Ƿĵַݸ");
  }
  else  {                                /* if inputs valid then              */
 	/* Read from I2C EEPROM from EEPROM_ReadAddress1 */
    I2C_EE_BufferRead(Rx1_Buffer, adr, num);
	for(i=0; i<(num/16); i++)
	{
	    printf("0x%2X ",adr+i*16);
		for(j=0; j<16; j++)  
		  printf("%2X ",Rx1_Buffer[i*16+j]);
		for(j=0; j<16; j++)
		  printf("%c",Rx1_Buffer[i*16+j]);
	    printf("\n");
	}
  }
}
/*------------------------------------------------------------------------------
  Write EEPROM
*------------------------------------------------------------------------------*/
void write_eeprom (char * buffer)
{
  int adr, num;                          /* temporary time values             */
  int args;                              /* number of arguments               */
  int i;
  char buf[256];
  int tmp;

  args = sscanf (buffer, "%x:%x",        /* scan input line for               */
                 &adr,                   /* adr, num                          */
                 &num);
  if (adr > 255  ||  num > 256 ||        /* check for valid inputs            */
      args < 1   ||  args == EOF)  {
    printf (ERROR_STR, "Ƿĵַݸ");
  }
  else  {                                /* if inputs valid then              */
    getline (&buf[0], sizeof (buf));     /* input command line          */

    for (i = 0; buf[i] != 0; i++)  {     /* convert to upper characters */
      buf[i] = toupper(buf[i]);
    }

    for (i = 0; buf[i] == ' '; i++);     /* skip blanks                 */

	for(i=0; i<num; i++)
	{
      args = sscanf (&buf[i*3], "%x ",
                     &tmp);
	  Tx1_Buffer[i] = tmp;
	}
 
    /* Write on I2C EEPROM from EEPROM_WriteAddress1 */
    I2C_EE_BufferWrite(Tx1_Buffer, adr, num); 
  }
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
